<template>
    <div :class="['map-target', !isSub ? 'isSub' : '']">
        <div class="map-tip-container" v-if="isSub">
            <div
                class="map-container"
                :element-loading-background="loadingColor"
                v-loading="loading"
            >
                <div :id="CQId"></div>
                <div :id="main9Id">
                    <div
                        :class="['ljxq', `grade-${ljxqGrade}`]"
                        @click="goToSub('ljxq')"
                    >
                        <i class="dot"></i>
                    </div>
                    <div
                        :class="['gxq', `grade-${gxqGrade}`]"
                        @click="goToSub('gxq')"
                    >
                        <i class="dot"></i>
                    </div>
                </div>
            </div>
            <div class="fdgz">
                <!-- {{
                    quarter === 2
                        ? '本季以23（平均值）为中线，上下各采取等分法分为两档，共划分四档。'
                        : '以正在推进中的国家级改革试点项目数量为评价内容，当季以平均值（14.68）为中线，上下各等分两档。'
                }} -->
            </div>
            <div class="map-tip">
                <div class="tip-item">
                    <div class="level-title">A档</div>
                    <div class="tip-text" v-if="year === 2023 && quarter === 2">
                        ≥31个
                    </div>
                    <div class="tip-text" v-else>
                        &nbsp;&nbsp;≥平均值（{{
                            meanObj.nationalProjectNumAvg
                        }}）<br />等分为两档，第1档
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">B档</div>
                    <div class="tip-text" v-if="year === 2023 && quarter === 2">
                        ≥23个 且 ＜31个
                    </div>
                    <div class="tip-text" v-else>
                        &nbsp;&nbsp;≥平均值（{{
                            meanObj.nationalProjectNumAvg
                        }}）<br />等分为两档，第2档
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">C档</div>
                    <div class="tip-text" v-if="year === 2023 && quarter === 2">
                        ≥16个 且 ＜23个
                    </div>
                    <div class="tip-text" v-else>
                        &nbsp;&nbsp;＜平均值（{{
                            meanObj.nationalProjectNumAvg
                        }}）<br />等分为两档，第1档
                    </div>
                </div>
                <div class="tip-item">
                    <div class="level-title">D档</div>
                    <!-- <div class="tip-text">第26—33位</div> -->
                    <div class="tip-text" v-if="year === 2023 && quarter === 2">
                        ＜16个
                    </div>
                    <div class="tip-text" v-else>
                        &nbsp;&nbsp;＜平均值（{{
                            meanObj.nationalProjectNumAvg
                        }}）<br />等分为两档，第2档
                    </div>
                </div>
            </div>
        </div>

        <div class="list-container">
            <air-table
            @loadComplete="loadComplete"
                :data="tableData"
                :tableColumn="tableColumn"
                :lsFd="lsFd"
                :isSub="isSub"
            ></air-table>
        </div>
    </div>
</template>

<script>
import airTable from './airTable.vue'
import mapTargetMixin from '@/mixins/mapTargetMixin.js'
export default {
    mixins: [mapTargetMixin],
    components: {
        airTable,
    },
    props: {
        options: {
            type: Object,
            default: () => {
                return {}
            },
        },
        CQId: {
            type: String,
            default: 'cq-contianer_1',
        },
        main9Id: {
            type: String,
            default: 'main9-contianer_1',
        },
        isClick: {
            type: Boolean,
            default: true,
        },
    },
    data() {
        return {
            tableColumn: [
                {label: '排名', prop: 'nationalProjectSn'},
                {label: '区县', prop: 'unitName'},
                {label: '项目数(个)', prop: 'nationalProjectNum'},
                {label: '得分', prop: 'nationalProjectScore'},
            ],
            typeNum: 'nationalProjectNum',
            typeGrade: 'nationalProjectGrade',
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.setIsSub()
        this.setTableColumn()
        this.initData()
        this.$bus.$on('changeDate', () => {
            this.setIsSub()
            this.setTableColumn()
            this.initData()
        })
        this.$root.$on('resize', () => {
            this.resize(500)
        })
    },
    methods: {
        setTableColumn() {
            let {year, quarter} = JSON.parse(
                sessionStorage.getItem('searchDate')
            )
            if (year === 2023 && quarter < 4 && quarter !== 0) {
                this.tableColumn = [
                    {label: '排名', prop: 'nationalProjectSn'},
                    {label: '区县', prop: 'unitName'},
                    {label: '实际值(个)', prop: 'nationalProjectNum'},
                ]
            } else {
                this.tableColumn = [
                    {label: '排名', prop: 'nationalProjectSn'},
                    {label: '区县', prop: 'unitName'},
                    {label: '实际值(个)', prop: 'nationalProjectNum'},
                    {label: '得分', prop: 'nationalProjectScore'},
                ]
            }
        },
        handleDetail(comp, unitName, type) {
            this.$router.push({
                path: '/DetailComponent',
                name: 'DetailComponent',
                query: {
                    unitName,
                    comp,
                    type,
                    numType: 'nationalNum',
                },
            })
        },
    },
}
</script>

<style lang="scss" scoped>
@import './target.scss';

.map-tip {
    bottom: 0;
}

.map-target {
    padding: 30PX 35PX;
}

.level-container {
    display: flex;
    flex-direction: column;
    height: 100%;
    // height: 765px;
    flex-wrap: wrap;
    row-gap: 0;
    align-content: flex-end;

    >* {
        width: 30.33%;
        // flex: 1;
        font-family: '微软雅黑', sans-serif !important;
    }

    .level-title {
        display: flex;
        align-items: center;
        justify-content: center;
        text-align: center;
        font-size: 24PX;
        font-weight: bold;
        // height: calc(100% / 17);
        height: 32PX;
        line-height: 32PX;
        margin-top: 20PX;

        &:last-child {
            margin-bottom: 5px;
        }
    }

    .level-title-A {
        margin-top: 0;
        background-color: #398C8F;
    }

    .level-title-B {
        background-color: #1970c1;
    }

    .level-title-C {
        background-color: #A3A355;
    }

    .level-title-D {
        background-color: #B0825C;
    }

    .level-title-E {
        background-color: #9B4E55;
    }

    .level-header,
    .level-content-item {
        align-items: center;
        // line-height: 30px;
        margin: 0;
        height: calc(100% / 18);

        span {
            text-align: center;
            font-size: 18px;
            // display: inline-block;
            // padding: 12px 2px;
            flex: 1;
            text-align: center;
            // color:#b1e3ff;

            &:first-child {
                flex: 1.3;
            }

            &:last-child {
                flex: 1;
            }
        }

    }
}
</style>
